# Copyright 2018 Yanis Guenane  <yanis@guenane.org>
# Author: Yanis Guenane  <yanis@guenane.org>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os

from dcifeeder.component import RsyncComponent
from dcifeeder.feeder import get_topic_from_name
from dcifeeder import settings


class AnsibleComponent(RsyncComponent):

    def __init__(self, metadata_url, archive_name='archive.tar'):
        super(AnsibleComponent, self).__init__(metadata_url,
                                               archive_name=archive_name)
        self.type = 'snapshot_ansible'
        prod, ver = self.name.split('-')[:2]
        self.topic_name = '-'.join((prod.capitalize(), ver, 'rpm'))

    @property
    def rsync_source_path(self):
        return os.path.join('redhat/nightly/ANSIBLE', self.name,
                            'compose/Server/x86_64/os/')

    @property
    def rsync_destination_path(self):
        return os.path.join(settings.CACHE_DIR, 'ansible',
                            get_topic_from_name(self.topic_name)['id'],
                            'Ansible-BUILD')

    def build_archive(self):
        pass
