# Copyright (C) 2018 Red Hat, Inc
# Author: Dimitri Savineau <dsavinea@redhat.com>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import logging
import requests

from dcifeeder.component import ReposyncComponent
from six.moves.urllib.parse import urlparse

logger = logging.getLogger(__name__)


class BaseOCPComponent(ReposyncComponent):

    def __init__(self, metadata_url, archive_name='archive.tar'):
        super(BaseOCPComponent, self).__init__(metadata_url,
                                               archive_name)
        self.topic_name = 'OCP-%s' % self.name.split('-')[1]
        self.healthy = self.is_status_file_correct()

    def retrieve_metadata(self, url):
        r = requests.get(url)

        repo = self.parse_repo_file(r.text)
        version = repo['base_url'].split('/')[-3]
        self.canonical_project_name = repo['name']
        self.name = '%s %s' % (repo['name'], version)
        self.url = repo['base_url']
        self.data = {
            'path': urlparse(repo['base_url']).path,
            'version': version,
            'repo_name': repo['name'],
        }

    def is_healthy(self):
        return self.healthy

    def is_status_file_correct(self):
        r = requests.get('%s/status.txt' % self.base_url)
        if r.status_code != 200 or r.text.rstrip() != 'COMPLETE':
            logger.error('status.txt: Missing or file content not COMPLETE')
            return False
        return True


class OCPComponent(BaseOCPComponent):

    def __init__(self, metadata_url, archive_name='archive.tar'):
        super(OCPComponent, self).__init__(metadata_url, archive_name)
        self.type = 'puddle_ocp'
