# Copyright 2018 Yanis Guenane  <yanis@guenane.org>
# Author: Yanis Guenane  <yanis@guenane.org>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import requests

from datetime import datetime
from dcifeeder.component import ReposyncComponent
from six.moves.urllib.parse import urlparse


class RDOComponent(ReposyncComponent):

    def __init__(self, metadata_url, archive_name='archive.tar'):
        super(RDOComponent, self).__init__(metadata_url, archive_name)
        self.type = 'snapshot_rdo'
        self.topic_name = self.canonical_project_name

    def retrieve_metadata(self, url):
        r = requests.get(url)

        repo = self.parse_repo_file(r.text)
        dt = datetime.strptime(
            r.headers['Last-Modified'], '%a, %d %b %Y %H:%M:%S GMT'
        )
        topic = self.metadata_url.split('/')[3].split('-')[1].capitalize()
        topic = 'RDO-%s' % topic
        version = repo['base_url'].split('/')[-1]

        self.canonical_project_name = topic
        self.name = '%s %s %s' % (
            topic, '%s-%s-%s' % (dt.year, dt.month, dt.day), version
        )
        self.url = repo['base_url']
        self.data = {
            'path': urlparse(repo['base_url']).path,
            'version': version,
            'repo_name': topic,
        }

    def is_healthy(self):
        return True
