# Copyright 2018 Yanis Guenane  <yanis@guenane.org>
# Author: Yanis Guenane  <yanis@guenane.org>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import requests

from dcifeeder.products.openstack.components.rdo import RDOComponent
from dcifeeder.topic import BaseTopic


class RDO(BaseTopic):

    def __init__(self):
        self.version = self.__class__.__name__[3:]
        self.name = 'RDO-%s' % self.version
        super(RDO, self).__init__()
        self.url = 'https://trunk.rdoproject.org/centos7-%s/current-passed-ci/delorean.repo' % self.version.lower()  # noqa
        dlrn_url = '%s/commit.yaml' % '/'.join(self.url.split('/')[:-1])

        rdo_component = RDOComponent(self.url)
        rdo_component.data['dlrn'] = \
            rdo_component.parse_dlrn_informations(
                requests.get(dlrn_url).text)

        self.components = [rdo_component]


class RDONewton(RDO):

    def __init__(self):
        super(RDONewton, self).__init__()


class RDOOcata(RDO):

    def __init__(self):
        super(RDOOcata, self).__init__()


class RDOPike(RDO):

    def __init__(self):
        super(RDOPike, self).__init__()


class RDOQueens(RDO):

    def __init__(self):
        super(RDOQueens, self).__init__()


class RDORocky(RDO):

    def __init__(self):
        super(RDORocky, self).__init__()
