# -*- coding: utf-8 -*-
# Copyright 2018 François Charlier <fcharlie@redhat.com>
# Author: François Charlier <fcharlie@redhat.com>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import requests

from xml.etree import ElementTree

from dcifeeder.component import ReposyncComponent


class HarnessComponent(ReposyncComponent):

    def __init__(self, metadata_url, archive_name='archive.tar'):
        super(HarnessComponent, self).__init__(metadata_url,
                                               archive_name)
        self.type = 'harness'
        self.topic_name = self.name[:7]

    def retrieve_metadata(self, url):
        # Use the system's CA bundle in which we added Red Hat Engineering's
        # CA anchor, used by this server.
        r = requests.get(url, verify="/etc/ssl/certs/ca-bundle.crt")

        tree = ElementTree.fromstring(r.text)
        revision = tree.findall(
            '{http://linux.duke.edu/metadata/repo}revision')[0].text

        self.name = 'harness-%s' % revision
        self.canonical_project_name = 'harness-%s' % revision
        self.url = '/'.join(url.split('/')[:-2])

    def is_healthy(self):
        return True
