# Copyright 2018 Yanis Guenane  <yanis@guenane.org>
# Author: Yanis Guenane  <yanis@guenane.org>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os
import shutil

from dcifeeder.component import RsyncComponent
from dcifeeder.feeder import get_topic_from_name
from dcifeeder import settings

from urlparse import urlparse


class RHELComponent(RsyncComponent):

    def __init__(self, metadata_url, component_type='Compose',
                 archive_name='archive.tar'):
        super(RHELComponent, self).__init__(metadata_url, archive_name)
        self.type = component_type
        self.topic_name = self.name[:6]

    @property
    def rsync_source_path(self):
        o = urlparse(self.url)

        source_path = 'redhat'
        source_path += o.path
        source_path += '/compose'
        if self.topic_name == 'RHEL-7':
            source_path += '/Server'
        elif self.topic_name == 'RHEL-8':
            source_path += '/BaseOS'
        else:
            raise ValueError
        source_path += '/x86_64/os/'
        return source_path

    @property
    def rsync_destination_path(self):
        topic = get_topic_from_name(self.topic_name)
        return os.path.join(settings.CACHE_DIR,
                            topic['product']['label'].lower(),
                            topic['id'],
                            'RHEL-BUILD')

    def sync(self):
        super(RHELComponent, self).sync()

        shutil.copyfile(
            os.path.join(self.component_path, 'extra_files.json'),
            os.path.join(self.canonical_project_name, 'extra_files.json')
        )
