# Copyright 2018 Yanis Guenane  <yanis@guenane.org>
# Author: Yanis Guenane  <yanis@guenane.org>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import logging

from dcifeeder.products.rhel.components.rhel import RHELComponent
from dcifeeder.products.rhel.components.hwcert import HWCertComponent
from dcifeeder.products.rhel.components.appstream import AppStreamComponent
from dcifeeder.products.rhel.components.harness import HarnessComponent
from dcifeeder.topic import BaseTopic

logger = logging.getLogger(__name__)


class RHEL(BaseTopic):

    def __init__(self):
        self.version = self.__class__.__name__[4:]
        self.name = 'RHEL-%s' % self.version
        super(RHEL, self).__init__()

    def add_hwcert_component(self):
        hwcert_url = 'http://hwcert-server.khw.lab.eng.bos.redhat.com/' \
            'packages/devel/RHEL%s/repodata/repomd.xml' % self.version
        hwcert_component = HWCertComponent(hwcert_url)
        hwcert_component.topic_name = self.components[0].topic_name
        self.components.append(hwcert_component)


class RHEL7(RHEL):

    def __init__(self):
        super(RHEL7, self).__init__()
        main_url = (
            'http://download-node-02.eng.bos.redhat.com/'
            'nightly/updates/RHEL-7.6/latest-RHEL-7.6/COMPOSE_ID')
        extra_url = (
            'http://download-node-02.eng.bos.redhat.com/'
            'nightly/EXTRAS-RHEL-7.6/latest-EXTRAS-7.6-RHEL-7/COMPOSE_ID')
        self.components = [
            # TODO: Compose should be renamed to something more meaningful
            # like 'base' or 'main'.
            RHELComponent(main_url, component_type='Compose'),
            RHELComponent(extra_url, component_type='extraos'),
        ]
        self.add_hwcert_component()


class RHEL8(RHEL):

    def __init__(self):
        super(RHEL8, self).__init__()
        main_url = (
            'http://download-node-02.eng.bos.redhat.com/'
            'nightly/latest-RHEL-8/COMPOSE_ID')
        self.components = [RHELComponent(main_url, component_type='Compose')]
        self.add_hwcert_component()
        self.add_appstream_component()
        self.add_harness_component()

    def add_appstream_component(self):
        appstream_url = 'http://download-node-02.eng.bos.redhat.com/' \
            'nightly/latest-RHEL-8/compose/AppStream/x86_64/os/' \
            'repodata/repomd.xml'
        appstream_component = AppStreamComponent(appstream_url)
        appstream_component.topic_name = self.components[0].topic_name
        self.components.append(appstream_component)

    def add_harness_component(self):
        harness_url = 'https://beaker.engineering.redhat.com/' \
            'harness/RedHatEnterpriseLinux8/repodata/repomd.xml'
        harness_component = HarnessComponent(harness_url)
        harness_component.topic_name = self.components[0].topic_name
        self.components.append(harness_component)
