# -*- coding: utf-8 -*-
# Copyright 2018 Yanis Guenane  <yanis@guenane.org>
# Author: Yanis Guenane  <yanis@guenane.org>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os

#######
#
# Important notice. These are the default values for the settings.
# If you want to override some/all of these, either:
#
# - Set the corresponding environment variable
# or
# - Override the setting in `local_settings.py` file in the same folder
#   (which you may need to create)
#
#######

# General Parameters for dci-feeder-api
#
LOG_DIR = os.getenv('LOG_DIR', '/var/www/html')
CACHE_DIR = os.getenv('CACHE_DIR', '/var/cache/dci-feeder-api')
HOST = os.getenv('DCIFEEDERAPI_HOST', '127.0.0.1')
PORT = int(os.getenv('DCIFEEDERAPI_PORT', '5000'))


# DCI Information
#
DCI_CS_URL = os.getenv('DCI_CS_URL', 'https://api.distributed-ci.io')
DCI_LOGIN = os.getenv('DCI_LOGIN', 'admin')
DCI_PASSWORD = os.getenv('DCI_PASSWORD', 'admin')

# Location where the files are pushed to be served as a yum repository
# This is an rsync target.
# Use: user@host:/full/path to rsync via ssh
# Use: [user@]host::module/path to use an rsync-server
# Use: /full/path to rsync on local fs
DCI_REPO_RSYNC_TARGET = os.getenv('DCI_PUBLIC_REPO_HOST',
                                  'root@repo.distributed-ci.io:/repo')


# Registry Information
#
DEST_REGISTRY_URL = os.getenv('DEST_REGISTRY_URL',
                              'registry.distributed-ci.io')
DEST_REGISTRY_USER = os.getenv('DEST_REGISTRY_USER', 'registry-user')
DEST_REGISTRY_PASSWORD = os.getenv('DEST_REGISTRY_PASSWORD',
                                   'registry-password')


# OpenShift Information
#
OPENSHIFT_URL = os.getenv(
    'OPENSHIFT_URL',
    'https://docker-registry.engineering.redhat.com:8443')
OPENSHIFT_USER = os.getenv('OPENSHIFT_USER', 'openshift-user')
OPENSHIFT_PASSWORD = os.getenv('OPENSHIFT_PASSWORD', 'openshift-password')

try:
    from local_settings import * # noqa
except ImportError:
    pass
