# Copyright 2018 Yanis Guenane  <yanis@guenane.org>
# Author: Yanis Guenane  <yanis@guenane.org>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import logging
import os

from dcifeeder import feeder
from dcifeeder import settings

logger = logging.getLogger(__name__)


class BaseTopic(object):

    def __init__(self):
        topic = feeder.get_topic_from_name(self.name)
        self.id = topic['id']
        self.product = topic['product']

    def post_component_sync(self, component):
        src_path = os.path.join(settings.CACHE_DIR, self.product['label'].lower(), self.id)
        rsync_target = os.path.join(settings.DCI_REPO_RSYNC_TARGET,
                                    self.product['label'].lower(),
                                    self.product['id'])
        logger.info('Running: post_component_sync from "%s" to "%s" ...' %
                    (src_path, rsync_target))

        feeder.run_command(
            ["sudo", "-u", "dci", "rsync", "-av", "-H", "-D", "--delete",
             src_path, rsync_target]
        )

        logger.info('... post_component_sync done.')

    def is_healthy(self):
        def component_healthy(component):
            return component.is_healthy()
        return all((component_healthy(component)
                    for component in self.components))
